import UIKit

extension UIView {
  
  func addShadowView(shadowRadius: CGFloat = 3.0) {
    //Remove previous shadow views
    superview?.viewWithTag(119900)?.removeFromSuperview()
    
    //Create new shadow view with frame
    let shadowView = UIView(frame: frame)
    shadowView.tag = 119900
    shadowView.layer.shadowColor = UIColor.black.cgColor
    shadowView.layer.shadowOffset = CGSize(width: 2, height: 3)
    shadowView.layer.masksToBounds = false
    
    shadowView.layer.shadowOpacity = 0.3
    shadowView.layer.shadowRadius = shadowRadius
    shadowView.layer.shadowPath = UIBezierPath(rect: bounds).cgPath
    shadowView.layer.rasterizationScale = UIScreen.main.scale
    shadowView.layer.shouldRasterize = true
    
    superview?.insertSubview(shadowView, belowSubview: self)
  }
}

extension UIView {
  @nonobjc func withAccessibilityIdentifier(_ accessibilityIdentifier: String) -> UIView? {
    return withAccessibilityIdentifier(accessibilityIdentifier, classType: UIView.self)
  }
  
  @nonobjc func withAccessibilityIdentifier<T: UIView>(_ accessibilityIdentifier: String, classType: T.Type) -> T? {
    if let selfObject = self as? T, self.accessibilityIdentifier == accessibilityIdentifier {
      return selfObject
    }
    for subview in self.subviews {
      if let match = subview.withAccessibilityIdentifier(accessibilityIdentifier, classType: classType) {
        return match
      }
    }
    return nil
  }
}

extension UIView {
  var allSubviews: [UIView] {
    return self.subviews.flatMap { [$0] + $0.allSubviews }
  }
}
