import UIKit

extension URL {
  
  var getFileAttributes: NSDictionary? {
    let path = self.path
    
    do {
      let attributes = try FileManager.default.attributesOfItem(atPath: path) as NSDictionary
      
      return attributes
    } catch {}
    
    return nil
  }
  
  var getFileAttributesOfURL: [FileAttributeKey: Any]? {
    let path = self.path
    
    do {
      let attributes = try FileManager.default.attributesOfItem(atPath: path)
      
      return attributes
    } catch {
      print(error.localizedDescription, #function)
    }
    
    return nil
  }
  
  var getDate: String {
    return getDate(self.getFileAttributesOfURL)
  }
  
  func getDate(_ attributes: [FileAttributeKey: Any]?) -> String {
    var stringDate = String()
    if let attributes = attributes, let fileDate = attributes[FileAttributeKey.creationDate] as? Date {

      if Calendar.current.isDateInToday(fileDate) {
        stringDate = "Today".localized
      } else if Calendar.current.isDateInYesterday(fileDate) {
        stringDate = "Yesterday".localized
      } else if Date().isSameWeekAsDate(fileDate) {
        stringDate = "This week".localized
      } else {
        stringDate = getDateInCurrentLocaleWithHour(fileDate)
      }
    }
    
    return stringDate
  }
  
  /// This function will return a current date in format ""Jan 23, 2017, 14:59:09""
  private func getDateInCurrentLocaleWithHour(_ date: Date = Date()) -> String {
    let currentLocale = Locale.current
    let dateFormatter = DateFormatter()
    let dateComponents = "y-MMM-d - H'-'ms"
    let dateFormat = DateFormatter.dateFormat(fromTemplate: dateComponents, options: 0, locale: currentLocale)
    dateFormatter.dateFormat = dateFormat
    
    return dateFormatter.string(from: date)
  }
  
  var isPDF: Bool {
    return pathExtension == "pdf"
  }
  
  var toData: Data? {
    return try? Data(contentsOf: self)
  }
}

