import UIKit
import PencilKit
import QuickLook
import PDFKit

class PencilKitViewController: QLPreviewController {
  override var editingInteractionConfiguration: UIEditingInteractionConfiguration {
    return .none
  }
  
  override func viewDidLoad() {
    super.viewDidLoad()
    setEditing(true, animated: true)
    perform(#selector(hideShare), with: self, afterDelay: 1.22)
    
    navigationController?.hidesBarsOnTap = true
  }
  
  @objc private func hideShare() {
    if let shareButton = (children.first?.view.subviews.last as? UIToolbar)?.items?.first {
      shareButton.isEnabled = false
      shareButton.tintColor = .clear
    }
    
    //This hides the share item
    if let add = self.children.first as? UINavigationController {
      add.view.subviews.filter { $0 is UINavigationBar }.first?.subviews.last?.isHidden = true
      
//      if let pencilButton = (add.view.subviews.filter { $0 is UINavigationBar }.first as? UINavigationBar)?.items?.last?.rightBarButtonItem as? UIBarButtonItem {
        //        pencilButton.action
        //        UIApplication.shared.sendAction(pencilButton.action!, to: pencilButton.target, from: self, for: nil)
        //        _ = pencilButton.target?.perform(pencilButton.action, with: nil)
//      }
    }
  }
}

extension DocumentPreviewViewController: QLPreviewControllerDataSource, QLPreviewControllerDelegate {
  func numberOfPreviewItems(in controller: QLPreviewController) -> Int {
    return 1
  }
  
  func previewController(_ controller: QLPreviewController,
                         previewItemAt index: Int) -> QLPreviewItem {
    let url = file!.fileURL as NSURL
    return url as QLPreviewItem
  }
  
  @available(iOS 13.0, *)
  func previewController(_ controller: QLPreviewController,
                         editingModeFor previewItem: QLPreviewItem) -> QLPreviewItemEditingMode {
    return .updateContents
  }
  
  func previewController(_ controller: QLPreviewController,
                         didUpdateContentsOf previewItem: QLPreviewItem) {
    DispatchQueue.main.async { [weak self] in
      self?.didUpdateContentsOf((previewItem as! NSURL) as URL)
    }
  }
  
  func previewController(_ controller: QLPreviewController,
                         didSaveEditedCopyOf previewItem: QLPreviewItem,
                         at modifiedContentsURL: URL) {
    didSaveEditedCopyOf((previewItem as! NSURL) as URL)
  }
  
  func didUpdateContentsOf(_ url: URL) {
    let pdfView = view.withAccessibilityIdentifier("pdfView", classType: CustomPDFView.self)
    pdfView?.document = PDFDocument(url: url)
  }
  
  func didSaveEditedCopyOf(_ modifiedContentsURL: URL) {
    let pdfView = view.withAccessibilityIdentifier("pdfView", classType: CustomPDFView.self)
    if let data = modifiedContentsURL.toData, let documentURL = pdfView?.document?.documentURL {
      try? data.write(to: documentURL)
      pdfView?.document = PDFDocument(url: documentURL)
      pdfView?.layoutDocumentView()
    }
  }
}
