//
//  AllFolderTableViewCell.swift
//  MiniScanner
//
//  Created by George Makhoul on 06/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

protocol AllFolderTableViewCellDelegate {
    func cellTapped(folder: AppConfigurator.Folder)
}

final class AllFolderTableViewCell: UIView {
    // MARK: - Outlets
    @IBOutlet weak var collectionView: UICollectionView!
    
    // MARK: - Properties
    var folders: [AppConfigurator.Folder] = []
    var delegate: AllFolderTableViewCellDelegate?
    
    // MARK: - LifeCycle
    override func awakeFromNib() {
        super.awakeFromNib()
        setupCollectionView()
    }
    
    private func setupCollectionView() {
        let layout = UICollectionViewFlowLayout()
        layout.scrollDirection = .horizontal
        layout.minimumLineSpacing = 10
        layout.minimumInteritemSpacing = 10
        self.collectionView.collectionViewLayout = layout
        self.collectionView.delegate = self
        self.collectionView.dataSource = self
        self.collectionView.register(UINib(nibName: "FolderCollectionViewCell", bundle: nil), forCellWithReuseIdentifier: "FolderCollectionViewCell")
        folders = AppConfigurator().getFolders()
        self.collectionView.reloadData()
    }
    
    func set(selectedFolder: AppConfigurator.Folder, delegate: AllFolderTableViewCellDelegate? ) {
        self.delegate = delegate
        for (index, _) in folders.enumerated() {
            if folders[index].savedName == selectedFolder.savedName {
                folders[index].isSelected = true
            } else {
                folders[index].isSelected = false
            }
        }
        self.collectionView.reloadData()
    }
}

extension AllFolderTableViewCell: UICollectionViewDelegateFlowLayout {
    func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAt indexPath: IndexPath) -> CGSize {
        let itemHeight = collectionView.frame.height / 2.2
        let itemWidth = collectionView.frame.width / 2
        return CGSize(width: itemWidth, height: itemHeight)
    }
}

extension AllFolderTableViewCell: UICollectionViewDelegate, UICollectionViewDataSource {
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        folders.count
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        if let cell = collectionView.dequeueReusableCell(withReuseIdentifier: "FolderCollectionViewCell", for: indexPath) as? FolderCollectionViewCell {
            cell.set(folder: folders[indexPath.row])
            return cell
        }
        return UICollectionViewCell()
    }
    
    func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
        for (index, _) in folders.enumerated() {
            folders[index].isSelected = false
        }
        folders[indexPath.row].isSelected = true
        collectionView.reloadData()
        delegate?.cellTapped(folder: folders[indexPath.row])
    }
    
    
}
