import UIKit

final class DocumentsTableViewCell: UITableViewCell {
  
  @IBOutlet private weak var thumbnailImageView: UIImageView!
  @IBOutlet private weak var containerImageView: UIView!
  @IBOutlet private weak var nameLabel: UILabel!
  @IBOutlet private weak var dateLabel: UILabel!
  @IBOutlet private weak var pageLabel: UILabel!
  
  struct Constants {
    static let cornerRadius: CGFloat = 6
    static let separatorInset: CGFloat = 76
  }
  
  override func awakeFromNib() {
    super.awakeFromNib()
    // Initialization code
    
    containerImageView.addShadowView(shadowRadius: Constants.cornerRadius)
    thumbnailImageView.layer.cornerRadius = Constants.cornerRadius
    thumbnailImageView.clipsToBounds = true
    containerImageView.layer.cornerRadius = Constants.cornerRadius
    separatorInset.left = Constants.separatorInset
    separatorInset.right = Constants.separatorInset
  }
  
  func configure(with viewModel: File, image: UIImage?) {
    thumbnailImageView.image = image
    nameLabel.text = viewModel.displayName
    dateLabel.text = viewModel.date
    pageLabel.text = viewModel.pagesCount
  }
}
