import UIKit

final class SettingsViewController: UITableViewController {
    
  private var viewModels: [SettingsViewModel] = []
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    // Do any additional setup after loading the view.
    setupViewModels()
  }
  
  private func setupViewModels() {
    navigationController?.navigationBar.prefersLargeTitles = true
    
    let isPhotoEditing = { isEditing in
      self.isPhotoEditing(isEditing)
    }
    
    let startsAppWithCamera = { isEnabled in
      self.startsAppWithCamera(isEnabled)
    }
    
    let showWalktroughAtLaunch = { isEnabled in
      self.showWalktroughAtLaunch(isEnabled)
    }
    
    let askOnSwipeDelete = { isEnabled in
      self.askOnDeleteSwipe(isEnabled)
    }
    
    let photoEditing = SettingsViewModel(imageName: "crop",
                                         title: "Allow gallery photo editing".localized,
                                         isSwitchOn: UserDefaults.standard.isPhotoEditigOn,
                                         isSwitcherOn: isPhotoEditing, type: .segment)
    
    let cameraEditing = SettingsViewModel(imageName: "camera",
                                         title: "Start camera at start up".localized,
                                         isSwitchOn: UserDefaults.standard.startsAppWithCamera,
                                         isSwitcherOn: startsAppWithCamera, type: .segment)
    
    let showWalktrough = SettingsViewModel(imageName: "paperplane",
                                         title: "Show walktrough at launch".localized,
                                         isSwitchOn: UserDefaults.standard.showWalktroughAtLaunch,
                                         isSwitcherOn: showWalktroughAtLaunch, type: .segment)
    
    let deleteDocument = SettingsViewModel(imageName: "trash",
                                         title: "Confirm on swipe delete?".localized,
                                         isSwitchOn: UserDefaults.standard.askOnSwipeDelete,
                                         isSwitcherOn: askOnSwipeDelete, type: .segment)
    
    let privacy = SettingsViewModel(imageName: "checkmark.shield", title: "Privacy Policy".localized,
                                    urlString: AppConfigurator.Settings.privacy.rawValue, type: .url)
    
    let terms = SettingsViewModel(imageName: "exclamationmark.shield", title: "Terms & Conditions".localized,
                                  urlString: AppConfigurator.Settings.terms.rawValue, type: .url)
    
    viewModels = [photoEditing, cameraEditing, deleteDocument, showWalktrough, privacy, terms]
    
    tableView.tableFooterView = UIView()
    tableView.delegate = self
    tableView.dataSource = self
    tableView.reloadData()
  }
  
  private func isPhotoEditing(_ isOn: Bool) {
    UserDefaults.standard.isPhotoEditigOn = isOn
    setupViewModels()
    tableView.reloadData()
  }
  
  private func startsAppWithCamera(_ isOn: Bool) {
    UserDefaults.standard.startsAppWithCamera = isOn
    setupViewModels()
    tableView.reloadData()
  }
  
  private func showWalktroughAtLaunch(_ isOn: Bool) {
    UserDefaults.standard.showWalktroughAtLaunch = isOn
    setupViewModels()
    tableView.reloadData()
  }
  
  private func askOnDeleteSwipe(_ isOn: Bool) {
    UserDefaults.standard.askOnSwipeDelete = isOn
    setupViewModels()
    tableView.reloadData()
  }
  
  override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
    return viewModels.count
  }
  
  override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
    guard let cell = tableView.dequeueReusableCell(withIdentifier: SettingsTableViewCell.ReuseIdentifier,
                                                   for: indexPath) as? SettingsTableViewCell else {
      return UITableViewCell()
    }
    
    cell.configure(with: viewModels[indexPath.row])
    return cell
  }
  
  override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
    let viewModel = viewModels[indexPath.row]
    
    switch viewModel.type {
    case .url:
      guard let urlString = viewModel.urlString else { return }
      presentSafariController(with: urlString)
    default:
      break
    }
  }
  
  override func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
    return 50.0
  }
}
